"""Test the STVDS regitering bug
"""
import sys
import grass.temporal as tgis
import grass.pygrass.utils as gutils
from grass.pygrass.vector import VectorTopo
from grass.pygrass.vector.geometry import Point, Line

OVR = True

def create_map_list():
    map_list = []
    for i in range(5):
        map_name = 'map_test{}'.format(i)
        with VectorTopo(map_name, mode='w', overwrite=OVR) as vect_map:
            map_id = '{}@{}'.format(map_name, gutils.getenv('MAPSET'))
            # write geometry
            vect_map.write(Point(1,1))
        # populate list
        map_list.append((map_id, i))
    return map_list


def register_maps_in_stds(stds_id, map_list):
    """Create a STDS, create one mapdataset for each map and
    register them in the temporal database
    """
    # create stds
    stds = tgis.open_new_stds(stds_id, 'stvds', 'relative',
                              "test", "", "mean", overwrite=OVR)

    # populate MapDataset objects list
    map_dts_lst = []
    for map_id, map_time in map_list:
        # create MapDataset
        map_dts = tgis.VectorDataset(map_id)
        # load spatial data from map
        map_dts.load()
        # set time
        map_dts.set_relative_time(map_time, None, 'seconds')
        # populate the list
        map_dts_lst.append(map_dts)
    # Register the maps
    tgis.register.register_map_object_list('vector', map_dts_lst, stds,
                                           delete_empty=True, unit='seconds')


def main():
    tgis.init()
    register_maps_in_stds('stvds_test', create_map_list())


if __name__ == "__main__":
    sys.exit(main())
